@@ -13,6 +13,7 @@
 ##############################################################################
 import asyncore
 import socket
+import threading
 import time
 import traceback
 
@@ -23,8 +24,6 @@ from waitress.buffers import (
 
 from waitress.parser import HTTPRequestParser
 
-from waitress.compat import thread
-
 from waitress.task import (
     ErrorTask,
     WSGITask,
@@ -73,9 +72,9 @@ class HTTPChannel(logging_dispatcher, object):
         self.creation_time = self.last_activity = time.time()
 
         # task_lock used to push/pop requests
-        self.task_lock = thread.allocate_lock()
+        self.task_lock = threading.Lock()
         # outbuf_lock used to access any outbuf
-        self.outbuf_lock = thread.allocate_lock()
+        self.outbuf_lock = threading.Lock()
 
         asyncore.dispatcher.__init__(self, sock, map=map)
 
@@ -221,7 +220,7 @@ class HTTPChannel(logging_dispatcher, object):
     def _flush_some_if_lockable(self):
         # Since our task may be appending to the outbuf, we try to acquire
         # the lock, but we don't block if we can't.
-        locked = self.outbuf_lock.acquire(0)
+        locked = self.outbuf_lock.acquire(False)
         if locked:
             try:
                 self._flush_some()
